import random 
import pandas as pd
import numpy as np
import DBDIpy as dbdi


def test_plot_adducts():
    
    testID = random.sample(range(1, 99), 3)
    testdata = pd.DataFrame(np.random.randint(100, 1000000, size = (100, 100)))
    
    
    fig = dbdi.plot_adducts(testID, testdata, metadata = None, transform = False)
    
    assert fig is not None
   
    

    
    
"""    
import numpy as np
from ms2deepscore.plotting import create_confusion_matrix_plot


def test_create_confusion_matrix_plot():
    reference_scores = np.random.random((100, 100))
    comparison_scores = np.random.random((100, 100))
    fig = create_confusion_matrix_plot(reference_scores, comparison_scores)
    assert fig is not None
    assert fig.get_axes()[0].get_xlabel() == "MS2DeepScore"
    assert fig.get_axes()[0].get_ylabel() == 'Tanimoto similarity'
    
    
import pprint
import sys
pprint.pprint(sys.path) 
    
sys.path.append('.')

"""